pub enum CommandName {
Show 13 variants
DeviceInfo,
ResetDeviceAndReconnect,
GetLogEntries,
SetForceAuditOption,
SetCommandAuditOption,
PutAuthenticationKey,
GenerateAsymmetricKey,
SignEd25519,
PutWrapKey,
ExportWrapped,
ImportWrapped,
DeleteObject,
GetObjectInfo,
}Expand description
The printable name of a Command.
Variants
DeviceInfo
Query the device state.
ResetDeviceAndReconnect
Reset the device to factory settings and reconnect afterwards.
GetLogEntries
Query the command log of the device and print it to standard output.
SetForceAuditOption
Change audit settings.
SetCommandAuditOption
Changes command audit settings.
PutAuthenticationKey
Put authentication key on the device.
GenerateAsymmetricKey
Generates a new asymmetric key on the device.
SignEd25519
Signs data using a ed25519 key.
PutWrapKey
Puts new wrapping key on the device.
ExportWrapped
Export object under wrap (encrypted).
ImportWrapped
Imports objects under wrap (encrypted).
DeleteObject
Permanently remove an object from the device.
GetObjectInfo
Query data about the object and print it to standard output.