pub enum FileBackedCommand {
Show 13 variants
DeviceInfo,
ResetDeviceAndReconnect,
GetLogEntries,
SetForceAuditOption(AuditOption),
SetCommandAuditOption {
command: Code,
setting: AuditOption,
},
PutAuthenticationKey {
info: KeyInfo,
delegated_caps: Capabilities,
passphrase_file: PathBuf,
},
GenerateAsymmetricKey {
info: KeyInfo,
},
SignEd25519 {
key_id: Id,
data: Vec<u8>,
},
PutWrapKey {
info: KeyInfo,
delegated_caps: Capabilities,
passphrase_file: PathBuf,
},
ExportWrapped {
wrap_key_id: Id,
object: ObjectId,
wrapped_file: PathBuf,
},
ImportWrapped {
wrap_key_id: Id,
wrapped_file: PathBuf,
},
DeleteObject(ObjectId),
GetObjectInfo(ObjectId),
}Expand description
A single command that is atomically executed against a YubiHSM2.
Different from Command, this enum does not assign data directly in its variants, but instead
relies on paths to files to read from or write to.
Variants
DeviceInfo
Query the device state.
ResetDeviceAndReconnect
Reset the device to factory settings and reconnect afterwards.
Note that this is a destructive operation and the authenticating user will need to have appropriate capabilities.
GetLogEntries
Query the command log of the device and print it to standard output.
SetForceAuditOption(AuditOption)
Change audit settings.
This mode prevents the device from performing additional operations when the Logs and Error Codes is full.
See Force Audit for more details.
SetCommandAuditOption
Changes command audit settings.
This is used to manage auditing options for specific commands. By default all commands are logged.
See Force Audit for more details.
Fields
setting: AuditOptionNew setting value.
PutAuthenticationKey
Put authentication key on the device.
This command is used to append new authentication keys.
Fields
delegated_caps: CapabilitiesAdditional delegated capabilities which would apply to objects that are created or imported.
GenerateAsymmetricKey
Generates new ed25519 signing key on the device.
SignEd25519
Signs data using provided ed25519 key.
Fields
PutWrapKey
Puts new wrapping key on the device.
This command is used to append new wrapping keys which serve as encryption keys for other objects.
Fields
delegated_caps: CapabilitiesAdditional delegated capabilities which would apply to objects that are created or imported.
ExportWrapped
Export object under wrap (encrypted).
Fields
ImportWrapped
Imports objects under wrap (encrypted).
Fields
DeleteObject(ObjectId)
Permanently remove an object from the device.
GetObjectInfo(ObjectId)
Query data about the object and print it to standard output.