Command

Enum Command 

pub enum Command {
Show 14 variants Info, Reset, GetLog, Auth(Auth), ForceAudit(AuditOption), CommandAudit { command: Code, setting: AuditOption, }, PutAuthKey { info: KeyInfo, delegated_caps: Capabilities, passphrase_file: PathBuf, }, GenerateKey { info: KeyInfo, }, SignEd25519 { key_id: u16, data: Vec<u8>, }, PutWrapKey { info: KeyInfo, delegated_caps: Capabilities, passphrase_file: PathBuf, }, ExportWrapped { wrap_key_id: u16, object: ObjectId, wrapped_file: PathBuf, }, ImportWrapped { wrap_key_id: u16, wrapped_file: PathBuf, }, Delete(ObjectId), GetInfo(ObjectId),
}
A single command that is atomically executed against a YubiHSM2.

Variants



Info

Query the device state.



Reset

Reset the device to factory settings and reconnect afterwards.

Note that this is a destructive operation and the authenticating user will need to have appropriate capabilities.



GetLog

Query the command log of the device and print it to standard output.



Auth(Auth)

Authenticate against the device.

This command must be used as a first command in the scenario file as it is not possible to connect to the device without any credentials.



ForceAudit(AuditOption)

Change audit settings.

This mode prevents the device from performing additional operations when the Logs and Error Codes is full.

See Force Audit for more details.



CommandAudit

Changes command audit settings.

This is used to manage auditing options for specific commands. By default all commands are logged.

See Force Audit for more details.

Fields

command: Code

Command of which the setting should be changed.

setting: AuditOption

New setting value.



PutAuthKey

Put authentication key on the device.

This command is used to append new authentication keys.

Fields

info: KeyInfo

The key identity and capabilities.

delegated_caps: Capabilities

Additional delegated capabilities which would apply to objects that are created or imported.

passphrase_file: PathBuf

The file containing passphrase of the authenticating user.



GenerateKey

Generates new ed25519 signing key on the device.

Fields

info: KeyInfo

The key identity and capabilities.



SignEd25519

Signs data using provided ed25519 key.

Fields

key_id: u16

The key to be used for signing.

data: Vec<u8>

Raw data blob which should be signed.



PutWrapKey

Puts new wrapping key on the device.

This command is used to append new wrapping keys which serve as encryption keys for other objects.

Fields

info: KeyInfo

The key identity and capabilities.

delegated_caps: Capabilities

Additional delegated capabilities which would apply to objects that are created or imported.

passphrase_file: PathBuf

The file containing raw value of the wrapping key.



ExportWrapped

Export object under wrap (encrypted).

Fields

wrap_key_id: u16

Wrapping key which should encrypt the exported object.

object: ObjectId

Object that will be exported.

wrapped_file: PathBuf

Output file which will contain the exported object encrypted with the wrapping key.



ImportWrapped

Imports objects under wrap (encrypted).

Fields

wrap_key_id: u16

Wrapping key which would decrypt the imported object.

wrapped_file: PathBuf

Input file which contains the imported object encrypted with the wrapping key.



Delete(ObjectId)

Permanently remove an object from the device.



GetInfo(ObjectId)

Query data about the object and print it to standard output.