ScenarioRunner

Struct ScenarioRunner 

pub struct ScenarioRunner {
    connector: Connector,
}
Runs commands against a physical or in-memory YubiHSM2 token.

Fields

connector: Connector

Implementations

Source

impl ScenarioRunner

pub fn new(connector: Connector) -> Self

Creates a new ScenarioRunner for a [Connector].

pub fn run(&self, scenario: &Scenario) -> Result<ScenarioReturnValue, Error>

Runs a Scenario.

Errors

Returns an error if executing one of the commands in the scenario fails.

Before returning the error, the return values of successfully executed commands will be emitted in an error message to the log.

pub fn run_with_writer( &self, scenario: &Scenario, writer: &mut dyn Write, ) -> Result<ScenarioReturnValue, Error>

Runs a Scenario.

The writer will receive JSONL-formatted responses for commands which generate them.

Errors

Returns an error if

  • executing the scenario fails
  • the return value of a command cannot be serialized and written to the writer.
fn run_command( &self, client: &mut Client, command: &Command, ) -> Result<CommandReturnValue, Error>

Runs a single Command and returns a CommandReturnValue for it.

Errors

Returns an error if

  • executing the command on device fails
  • reading or writing associated files fails