pub struct Scenario {
pub auth: Auth,
pub steps: Vec<Command>,
}Expand description
Describes a series of commands to be executed against a YubiHSM2.
The auth parameter indicates initial authentication data.
The set of commands to be executed is processed in a sequential manner.
The additional Auth command may be used to re-authenticate as another user while executing the
scenario.
Fields
auth: AuthInitial authentication data required to establish the connection to a YubiHSM2.
steps: Vec<Command>Commands to be executed.