pub enum WrappedPayload<'a> {
ExpandedEd25519(ExpandedEd25519KeyData<'a>),
SeedEd25519(SeedEd25519KeyData<'a>),
AuthAes128(AuthAes128<'a>),
Opaque(&'a [u8]),
}Expand description
The deserialized body of a wrapped object.
This usually is the private key material for a signing or authentication object. However, it can also represent raw binary data, which may have no specific purpose in the context of the cryptographic functionalities of the YubiHSM2 hardware.
Variants
ExpandedEd25519(ExpandedEd25519KeyData<'a>)
Ed25519 private key parts without the private key seed.
SeedEd25519(SeedEd25519KeyData<'a>)
Ed25519 private key parts with the private key seed.
AuthAes128(AuthAes128<'a>)
AES-128-based authentication key.
Opaque(&'a [u8])
Raw binary data.
Implementations
Sourceimpl<'a> WrappedPayload<'a>
impl<'a> WrappedPayload<'a>
Sourcefn parse(
object_type: ObjectType,
bytes: &'a [u8],
) -> Result<WrappedPayload<'a>, Error>
fn parse( object_type: ObjectType, bytes: &'a [u8], ) -> Result<WrappedPayload<'a>, Error>
Parses raw bytes of specified object type into a WrappedPayload structure.
Depending on the ObjectType the expected shape of bytes differs:
- for ed25519 keys two forms are accepted: expanded (exactly 96 bytes) and seeded (128 bytes)
- for AES-128 authentication keys,
bytesneed to be exactly 40 bytes long (8 bytes for delecated capabilities and 32 for a pair of AES-128 keys) - opaque does not make any restrictions and will accept any
bytes
Errors
Returns an Error if:
- private key material length is incorrect
Sourcefn serialize_into(&self, buffer: &mut Vec<u8>)
fn serialize_into(&self, buffer: &mut Vec<u8>)
Serializes itself into the provided buffer.