pub struct Label([u8; 40]);Expand description
Tuple Fields
0: [u8; 40]Trait Implementations
Sourceimpl Display for Label
impl Display for Label
Sourcefn fmt(&self, f: &mut Formatter<'_>) -> Result
fn fmt(&self, f: &mut Formatter<'_>) -> Result
Converts the label to a string and writes it to a given formatter.
Note that if the underlying buffer does not contain valid UTF-8 data, the conversion is lossy.
Examples
use std::fmt::Write;
use signstar_yubihsm2::backup::Label;
let label: Label = "test".parse()?;
let mut str = String::new();
write!(str, "{label}")?;
assert_eq!(str, "test");Sourceimpl FromStr for Label
impl FromStr for Label
Sourcefn from_str(s: &str) -> Result<Self, Self::Err>
fn from_str(s: &str) -> Result<Self, Self::Err>
Creates a new Label from a string slice.
The text must be no longer than 40 bytes and may be empty.
Examples
Converting a string to Label:
use signstar_yubihsm2::backup::{Error, Label};
let label: Label = "test".parse()?;
assert_eq!(label.to_string(), "test");
// When the string is too long [`Error::LabelLength`] is returned:
assert!(matches!(
"a".repeat(50).parse::<Label>(),
Err(Error::LabelLength { .. })
));Errors
Returns an error if the string is longer than 40 bytes.