pub struct SerializedEd25519([u8; 128]);Expand description
An Ed25519 key serialized in YubiHSM2 specific format.
The serialized form, as accepted by the YubiHSM2, consists of four 32-byte values:
- secret key seed, from with the scalar and hash-prefix are derived,
- scalar value, used directly for signing,
- hash prefix, which is a domain separator used when hashing the message to generate the
pseudorandom
rvalue, - public key, used for verifying signed data.
Tuple Fields
0: [u8; 128]Trait Implementations
Sourceimpl AsRef<[u8]> for SerializedEd25519
impl AsRef<[u8]> for SerializedEd25519
Sourceimpl Debug for SerializedEd25519
impl Debug for SerializedEd25519