pub enum Capability {
Show 56 variants
ChangeAuthenticationKey,
CreateOtpAead,
DecryptCbc,
DecryptEcb,
DecryptOaep,
DecryptOtp,
DecryptPkcs,
DeleteAsymmetricKey,
DeleteAuthenticationKey,
DeleteHmacKey,
DeleteOpaque,
DeleteOtpAeadKey,
DeletePublicWrapKey,
DeleteSymmetricKey,
DeleteTemplate,
DeleteWrapKey,
DeriveEcdh,
EncryptCbc,
EncryptEcb,
ExportableUnderWrap,
ExportWrapped,
GenerateAsymmetricKey,
GenerateHmacKey,
GenerateOtpAeadKey,
GenerateSymmetricKey,
GenerateWrapKey,
GetLogEntries,
GetOpaque,
GetOption,
GetPseudoRandom,
GetTemplate,
ImportWrapped,
PutAsymmetricKey,
PutAuthenticationKey,
PutHmacKey,
PutOpaque,
PutOtpAeadKey,
PutPublicWrapKey,
PutSymmetricKey,
PutTemplate,
PutWrapKey,
RandomizeOtpAead,
ResetDevice,
RewrapFromOtpAeadKey,
RewrapToOtpAeadKey,
SetOption,
SignAttestationCertificate,
SignEcdsa,
SignEddsa,
SignHmac,
SignPkcs,
SignPss,
SignSshCertificate,
UnwrapData,
VerifyHmac,
WrapData,
}Expand description
A capability of an object stored on a YubiHSM2.
Variants
ChangeAuthenticationKey
Replace authentication key objects.
Applicable for authentication key objects.
CreateOtpAead
Create OTP AEAD.
Applicable for authentication and OTP AEAD key objects.
DecryptCbc
Decrypt data using AES CBC mode.
Applicable for authentication and symmetric key objects.
DecryptEcb
Decrypt data using AES ECB mode.
Applicable for authentication and symmetric key objects.
DecryptOaep
Decrypt data using RSA-OAEP.
Applicable for authentication and asymmetric key objects.
DecryptOtp
Decrypt OTP.
Applicable for authentication and OTP AEAD key objects.
DecryptPkcs
Decrypt data using RSA-PKCS1v1.5.
Applicable for authentication and asymmetric key objects.
DeleteAsymmetricKey
Delete asymmetric key objects.
Applicable for authentication key objects.
DeleteAuthenticationKey
Delete authentication key objects.
Applicable for authentication key objects.
DeleteHmacKey
Delete HMAC key objects.
Applicable for authentication key objects.
DeleteOpaque
Delete opaque objects.
Applicable for authentication key objects.
DeleteOtpAeadKey
Delete OTP AEAD key objects.
Applicable for authentication key objects.
DeletePublicWrapKey
Delete RSA public wrap key.
Applicable for authentication and wrap key objects.
DeleteSymmetricKey
Delete AES key.
Applicable for authentication key objects.
DeleteTemplate
Delete template objects.
Applicable for authentication key objects.
DeleteWrapKey
Delete wrap key objects.
Applicable for authentication key objects.
DeriveEcdh
Perform ECDH.
Applicable for authentication and asymmetric key objects.
EncryptCbc
Encrypt data using AES CBC mode.
Applicable for authentication and symmetric key objects.
EncryptEcb
Encrypt data using AES ECB mode.
Applicable for authentication and symmetric key objects.
ExportableUnderWrap
The object can be exported under wrap (encrypted).
Applicable for all objects.
ExportWrapped
Export other objects under wrap.
Applicable for authentication and wrap key objects.
Note
Both the authentication key used for export and the wrapping key need to be capable of export.
GenerateAsymmetricKey
Generate asymmetric key objects.
Applicable for authentication key objects.
GenerateHmacKey
Generate HMAC key objects.
Applicable for authentication key objects.
GenerateOtpAeadKey
Generate OTP AEAD key objects.
Applicable for authentication key objects.
GenerateSymmetricKey
Generate AES key.
Applicable for authentication key objects.
GenerateWrapKey
Generate wrap key objects.
Applicable for authentication key objects.
GetLogEntries
Read the log store.
Applicable for authentication key objects.
GetOpaque
Read opaque objects.
Applicable for authentication key objects.
GetOption
Read device-global options.
Applicable for authentication key objects.
GetPseudoRandom
Extract random bytes.
Applicable for authentication key objects.
GetTemplate
Read template objects.
Applicable for authentication key objects.
ImportWrapped
Import wrapped objects.
Applicable for authentication and wrap key objects.
Note
Both the authentication key used for import and the wrapping key need to be capable of import.
PutAsymmetricKey
Write asymmetric key objects.
Applicable for authentication key objects.
PutAuthenticationKey
Write authentications key objects.
Applicable for authentication key objects.
PutHmacKey
Write HMAC key objects.
Applicable for authentication key objects.
PutOpaque
Write opaque objects.
Applicable for authentication key objects.
PutOtpAeadKey
Write OTP AEAD key objects.
Applicable for authentication key objects.
PutPublicWrapKey
Write RSA public wrap key.
Applicable for authentication and wrap key objects.
PutSymmetricKey
Import AES key.
Applicable for authentication key objects.
PutTemplate
Write template objects.
Applicable for authentication key objects.
PutWrapKey
Write wrap key objects.
Applicable for authentication key objects.
RandomizeOtpAead
Create OTP AEAD from random data.
Applicable for authentication and OTP AEAD key objects.
ResetDevice
Perform a factory reset on the device.
Applicable for authentication key objects.
RewrapFromOtpAeadKey
Rewrap AEADs from one OTP AEAD key to another.
Applicable for authentication and OTP AEAD key objects.
RewrapToOtpAeadKey
Rewrap AEADs to one OTP AEAD key from another.
Applicable for authentication and OTP AEAD key objects.
SetOption
Write device-global options.
Applicable for authentication key objects.
SignAttestationCertificate
Attest properties of asymmetric key objects.
Applicable for authentication and asymmetric key objects.
SignEcdsa
Compute digital signatures using ECDSA.
Applicable for authentication and asymmetric key objects.
SignEddsa
Compute digital signatures using EdDSA.
Applicable for authentication and asymmetric key objects.
SignHmac
Compute HMAC of data.
Applicable for authentication and HMAC key objects.
SignPkcs
Compute digital signatures using RSA-PKCS1v1.5.
Applicable for authentication and asymmetric key objects.
SignPss
Compute digital signatures using RSA-PSS.
Applicable for authentication and asymmetric key objects.
SignSshCertificate
Sign SSH certificates.
Applicable for authentication and asymmetric key objects.
UnwrapData
Unwrap user-provided data.
Applicable for authentication and wrap key objects.
VerifyHmac
Verify HMAC of data.
Applicable for authentication and HMAC key objects.
WrapData
Wrap user-provided data.
Applicable for authentication and wrap key objects.