pub struct Id(NonZeroU16);Expand description
The fundamental representation of an object identifier.
Wraps NonZeroU16 to reflect on the limitations imposed by a YubiHSM2 [Object ID].
Note
Limits the allowed values to a maximum of 256.
Tuple Fields
0: NonZeroU16Implementations
Sourceimpl Id
impl Id
Sourcepub fn new(num: NonZeroU16) -> Result<Self, Error>
pub fn new(num: NonZeroU16) -> Result<Self, Error>
Creates a new Id from a NonZeroU16.
Sourcepub fn get(&self) -> NonZeroU16
pub fn get(&self) -> NonZeroU16
Returns the inner NonZeroU16.