pub struct KeyInfo {
pub key_id: u16,
pub domain: Domain,
pub caps: Capabilities,
}Expand description
Metadata about a key stored on a YubiHSM2.
This struct stores common parameters of keys regardless of their usage may describe authentication, wrapping and signing keys.
Fields
key_id: u16Inner identifier used to track the key on the YubiHSM2.
domain: DomainKey domain.
Must be in range 1..16.
See Core Concepts - Domains.
caps: CapabilitiesCapabilities of this key.