pub struct WrapKeyFromPassphrase<'passphrase> {
passphrase: &'passphrase Passphrase,
kind: WrapKeyKind,
}Expand description
A helper struct for the creation of a WrapKey from a Passphrase.
The struct tracks a Passphrase and a WrapKeyKind.
The passphrase is guaranteed to be validated against the passphrase policy imposed by
WrapKey.
Fields
passphrase: &'passphrase Passphrasekind: WrapKeyKindImplementations
Sourceimpl<'passphrase> WrapKeyFromPassphrase<'passphrase>
impl<'passphrase> WrapKeyFromPassphrase<'passphrase>
Sourcepub(crate) const ARGON2_SALT: &'static [u8] = b"Salt for a Signstar backup key"
pub(crate) const ARGON2_SALT: &'static [u8] = b"Salt for a Signstar backup key"
The static salt used for argon2, when hashing a passphrase.
Sourcepub fn new(
passphrase: &'passphrase Passphrase,
kind: WrapKeyKind,
) -> Result<Self, Error>
pub fn new( passphrase: &'passphrase Passphrase, kind: WrapKeyKind, ) -> Result<Self, Error>
Creates a new WrapKeyFromPassphrase.
Note
It is recommended to use WrapKeyKind::Aes256 for kind, as it is considered resistant
against quantum attacks.
Errors
Returns an error, if checking passphrase against WrapKey::PASSPHRASE_POLICY fails.