FileBackedCredentials

Struct FileBackedCredentials 

pub struct FileBackedCredentials {
    pub(crate) id: Id,
    passphrase_file: PathBuf,
}
Credentials for a YubiHSM2 device, that are backed by a UTF-8 encoded passphrase file.

Credentials are mapped to the authentication key ID and the passphrase file. The contents of the passphrase file are meant to be used as input to the key derivation function (KDF) for an authentication key.

Fields

id: Idpassphrase_file: PathBuf