Capability

Struct Capability 

pub struct Capability(<Capability as PublicFlags>::Internal);
Object attributes specifying which operations are allowed to be performed

https://developers.yubico.com/YubiHSM2/Concepts/Capability.html

Tuple Fields

0: <Capability as PublicFlags>::Internal

Implementations



impl Capability

pub const DERIVE_ECDH: Capability

derive-ecdh: perform ECDH operation

pub const DECRYPT_OAEP: Capability

decrypt-oaep: perform RSA-OAEP decryption

pub const DECRYPT_PKCS: Capability

decrypt-pkcs: perform RSA-PKCS1v1.5 decryption

pub const GENERATE_ASYMMETRIC_KEY: Capability

generate-asymmetric-key: generate asymmetric objects

pub const SIGN_ECDSA: Capability

sign-ecdsa: compute ECDSA digital signature

pub const SIGN_EDDSA: Capability

sign-eddsa: compute EdDSA (i.e. Ed25519) digital signature

pub const SIGN_PKCS: Capability

sign-pkcs: compute RSA-PKCS1v1.5 digital signature

pub const SIGN_PSS: Capability

sign-pss: compute RSA-PSS digital signature

pub const SIGN_ATTESTATION_CERTIFICATE: Capability

sign-attestation-certificate: create attestation (i.e. X.509 certificate) about an asymmetric object

pub const GET_LOG_ENTRIES: Capability

get-log-entries: read the log store

pub const DELETE_ASYMMETRIC_KEY: Capability

delete-asymmetric-key: delete asymmetric key objects

pub const DELETE_AUTHENTICATION_KEY: Capability

delete-authentication-key: delete authentication::Key objects

pub const DELETE_HMAC_KEY: Capability

delete-hmac-key: delete HMACKey objects

pub const DELETE_OPAQUE: Capability

delete-opaque: delete opaque objects

pub const DELETE_OTP_AEAD_KEY: Capability

delete-otp-aead-key: delete Yubic OTP AEAD key objects

pub const DELETE_TEMPLATE: Capability

delete-template: delete template objects

pub const DELETE_WRAP_KEY: Capability

delete-wrap-key: delete WrapKey objects

pub const EXPORTABLE_UNDER_WRAP: Capability

exportable-under-wrap: mark an object as exportable under keywrap

pub const EXPORT_WRAPPED: Capability

export-wrapped: export objects under keywrap

pub const GENERATE_OTP_AEAD_KEY: Capability

generate-otp-aead-key: generate Yubico OTP AEAD objects

pub const GENERATE_WRAP_KEY: Capability

generate-wrap-key: generate wrapkey objects

pub const GET_OPAQUE: Capability

get-opaque: read opaque objects

pub const GET_OPTION: Capability

get-option: read device-global options

pub const GET_PSEUDO_RANDOM: Capability

get-pseudo-random: extract random bytes

pub const GET_TEMPLATE: Capability

get-template: read SSH template objects

pub const GENERATE_HMAC_KEY: Capability

generate-hmac-key: generate HMAC key objects

pub const SIGN_HMAC: Capability

sign-hmac: compute HMAC for data

pub const VERIFY_HMAC: Capability

verify-hmac: verify HMAC for data

pub const IMPORT_WRAPPED: Capability

import-wrapped: import keywrapped objects

pub const CREATE_OTP_AEAD: Capability

create-otp-aead: create an OTP AEAD

pub const RANDOMIZE_OTP_AEAD: Capability

randomize-otp-aead: create an OTP AEAD from random data

pub const REWRAP_FROM_OTP_AEAD_KEY: Capability

rewrap-from-otp-aead-key: rewrap AEADs from an OTP AEAD key object to another

pub const REWRAP_TO_OTP_AEAD_KEY: Capability

rewrap-to-otp-aead-key: rewrap AEADs to an OTP AEAD key object from another

pub const DECRYPT_OTP: Capability

decrypt-otp: decrypt OTP

pub const PUT_ASYMMETRIC_KEY: Capability

put-asymmetric-key: write asymmetric objects

pub const PUT_AUTHENTICATION_KEY: Capability

put-authentication-key: write authentication key objects

pub const PUT_HMAC_KEY: Capability

put-hmac-key: write HMAC key objects

pub const PUT_OPAQUE: Capability

put-opaque: Write Opaque Objects

pub const PUT_OPTION: Capability

set-option: write device-global options

pub const PUT_OTP_AEAD_KEY: Capability

put-otp-aead-key: write OTP AEAD key objects

pub const PUT_TEMPLATE: Capability

put-template: write template objects

pub const PUT_WRAP_KEY: Capability

put-wrap-key: write WrapKey objects

pub const RESET_DEVICE: Capability

reset-device: factory reset the device

pub const SIGN_SSH_CERTIFICATE: Capability

sign-ssh-certificate: sign SSH certificates

pub const UNWRAP_DATA: Capability

unwrap-data: unwrap user-provided data

pub const WRAP_DATA: Capability

wrap-data: wrap user-provided data

pub const CHANGE_AUTHENTICATION_KEY: Capability

change-authentication-key: overwrite existing authentication key with new one

pub const UNKNOWN_CAPABILITY_47: Capability

unknown capability: bit 47

pub const UNKNOWN_CAPABILITY_48: Capability

unknown capability: bit 48

pub const UNKNOWN_CAPABILITY_49: Capability

unknown capability: bit 49

pub const UNKNOWN_CAPABILITY_50: Capability

unknown capability: bit 50

pub const UNKNOWN_CAPABILITY_51: Capability

unknown capability: bit 51

pub const UNKNOWN_CAPABILITY_52: Capability

unknown capability: bit 52

pub const UNKNOWN_CAPABILITY_53: Capability

unknown capability: bit 53

pub const UNKNOWN_CAPABILITY_54: Capability

unknown capability: bit 54

pub const UNKNOWN_CAPABILITY_55: Capability

unknown capability: bit 55

pub const UNKNOWN_CAPABILITY_56: Capability

unknown capability: bit 56

pub const UNKNOWN_CAPABILITY_57: Capability

unknown capability: bit 57

pub const UNKNOWN_CAPABILITY_58: Capability

unknown capability: bit 58

pub const UNKNOWN_CAPABILITY_59: Capability

unknown capability: bit 59

pub const UNKNOWN_CAPABILITY_60: Capability

unknown capability: bit 60

pub const UNKNOWN_CAPABILITY_61: Capability

unknown capability: bit 61

pub const UNKNOWN_CAPABILITY_62: Capability

unknown capability: bit 62

pub const UNKNOWN_CAPABILITY_63: Capability

unknown capability: bit 63



impl Capability

pub const fn empty() -> Capability

Get a flags value with all bits unset.

pub const fn all() -> Capability

Get a flags value with all known bits set.

pub const fn bits(&self) -> u64

Get the underlying bits value.

The returned value is exactly the bits set in this flags value.

pub const fn from_bits(bits: u64) -> Option<Capability>

Convert from a bits value.

This method will return None if any unknown bits are set.

pub const fn from_bits_truncate(bits: u64) -> Capability

Convert from a bits value, unsetting any unknown bits.

pub const fn from_bits_retain(bits: u64) -> Capability

Convert from a bits value exactly.

pub fn from_name(name: &str) -> Option<Capability>

Get a flags value with the bits of a flag with the given name set.

This method will return None if name is empty or doesn’t correspond to any named flag.

pub const fn is_empty(&self) -> bool

Whether all bits in this flags value are unset.

pub const fn is_all(&self) -> bool

Whether all known bits in this flags value are set.

pub const fn intersects(&self, other: Capability) -> bool

Whether any set bits in a source flags value are also set in a target flags value.

pub const fn contains(&self, other: Capability) -> bool

Whether all set bits in a source flags value are also set in a target flags value.

pub fn insert(&mut self, other: Capability)

The bitwise or (|) of the bits in two flags values.

pub fn remove(&mut self, other: Capability)

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. remove won’t truncate other, but the ! operator will.

pub fn toggle(&mut self, other: Capability)

The bitwise exclusive-or (^) of the bits in two flags values.

pub fn set(&mut self, other: Capability, value: bool)

Call insert when value is true or remove when value is false.

pub const fn intersection(self, other: Capability) -> Capability

The bitwise and (&) of the bits in two flags values.

pub const fn union(self, other: Capability) -> Capability

The bitwise or (|) of the bits in two flags values.

pub const fn difference(self, other: Capability) -> Capability

The intersection of a source flags value with the complement of a target flags value (&!).

This method is not equivalent to self & !other when other has unknown bits set. difference won’t truncate other, but the ! operator will.

pub const fn symmetric_difference(self, other: Capability) -> Capability

The bitwise exclusive-or (^) of the bits in two flags values.

pub const fn complement(self) -> Capability

The bitwise negation (!) of the bits in a flags value, truncating the result.



impl Capability

pub const fn iter(&self) -> Iter<Capability>

Yield a set of contained flags values.

Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.

pub const fn iter_names(&self) -> IterNames<Capability>

Yield a set of contained named flags values.

This method is like iter, except only yields bits in contained named flags. Any unknown bits, or bits not corresponding to a contained flag will not be yielded.