pub enum Command {
Show 14 variants
Info,
Reset,
GetLog,
Auth(Auth),
ForceAudit(AuditOption),
CommandAudit {
command: Code,
setting: AuditOption,
},
PutAuthKey {
info: KeyInfo,
delegated_caps: Capabilities,
passphrase_file: PathBuf,
},
GenerateKey {
info: KeyInfo,
},
SignEd25519 {
key_id: u16,
data: Vec<u8>,
},
PutWrapKey {
info: KeyInfo,
delegated_caps: Capabilities,
passphrase_file: PathBuf,
},
ExportWrapped {
wrap_key_id: u16,
object: ObjectId,
wrapped_file: PathBuf,
},
ImportWrapped {
wrap_key_id: u16,
wrapped_file: PathBuf,
},
Delete(ObjectId),
GetInfo(ObjectId),
}Expand description
A single command that is atomically executed against a YubiHSM2.
Variants
Info
Query the device state.
Reset
Reset the device to factory settings and reconnect afterwards.
Note that this is a destructive operation and the authenticating user will need to have appropriate capabilities.
GetLog
Query the command log of the device and print it to standard output.
Auth(Auth)
Authenticate against the device.
This command must be used as a first command in the scenario file as it is not possible to connect to the device without any credentials.
ForceAudit(AuditOption)
Change audit settings.
This mode prevents the device from performing additional operations when the Logs and Error Codes is full.
See Force Audit for more details.
CommandAudit
Changes command audit settings.
This is used to manage auditing options for specific commands. By default all commands are logged.
See Force Audit for more details.
Fields
command: CodeCommand of which the setting should be changed.
setting: AuditOptionNew setting value.
PutAuthKey
Put authentication key on the device.
This command is used to append new authentication keys.
Fields
delegated_caps: CapabilitiesAdditional delegated capabilities which would apply to objects that are created or imported.
GenerateKey
Generates new ed25519 signing key on the device.
SignEd25519
Signs data using provided ed25519 key.
Fields
PutWrapKey
Puts new wrapping key on the device.
This command is used to append new wrapping keys which serve as encryption keys for other objects.
Fields
delegated_caps: CapabilitiesAdditional delegated capabilities which would apply to objects that are created or imported.
ExportWrapped
Export object under wrap (encrypted).
Fields
ImportWrapped
Imports objects under wrap (encrypted).
Fields
Delete(ObjectId)
Permanently remove an object from the device.
GetInfo(ObjectId)
Query data about the object and print it to standard output.