pub struct FileBackedCredentials {
pub(crate) id: Id,
passphrase_file: PathBuf,
}Expand description
Credentials for a YubiHSM2 device, that are backed by a UTF-8 encoded passphrase file.
Credentials are mapped to the authentication key ID and the passphrase file. The contents of the passphrase file are meant to be used as input to the key derivation function (KDF) for an authentication key.
Fields
id: Idpassphrase_file: PathBufTrait Implementations
Sourceimpl Debug for FileBackedCredentials
impl Debug for FileBackedCredentials
Sourceimpl<'de> Deserialize<'de> for FileBackedCredentials
impl<'de> Deserialize<'de> for FileBackedCredentials
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Serialize for FileBackedCredentials
impl Serialize for FileBackedCredentials
Sourceimpl TryFrom<&FileBackedCredentials> for Credentials
impl TryFrom<&FileBackedCredentials> for Credentials
Sourcefn try_from(value: &FileBackedCredentials) -> Result<Self, Self::Error>
fn try_from(value: &FileBackedCredentials) -> Result<Self, Self::Error>
Creates a new [yubihsm::Credentials] from a FileBackedCredentials.
Errors
Returns an error if a Credentials cannot be created from the provided
FileBackedCredentials.
Sourceimpl TryFrom<&FileBackedCredentials> for Credentials
impl TryFrom<&FileBackedCredentials> for Credentials
Sourcefn try_from(value: &FileBackedCredentials) -> Result<Self, Self::Error>
fn try_from(value: &FileBackedCredentials) -> Result<Self, Self::Error>
Creates a new Credentials from a FileBackedCredentials.
Errors
Returns an error if a Passphrase cannot be read from the passphrase file path of the
provided FileBackedCredentials.